package jp.gr.java_conf.akabeko.testtabactivity;

import android.app.TabActivity;
import android.content.Intent;
import android.content.res.Resources;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageView;
import android.widget.TabHost;
import android.widget.TextView;
import android.widget.TabHost.TabSpec;

/**
 * タブ画面を表します。
 */
public class TabHostActivity extends TabActivity {
	/**
	 * レイアウト指定を表すリソース識別子のパラメータ名。
	 */
	public static final String LAYOUT_ID = "LAYOUT_ID";

	/**
	 * レイアウト名を表す文字列のパラメータ名。
	 */
	public static final String LAYOUT_NAME = "LAYOUT_NAME";

	/**
	 * タブの配置方法を表す真偽値のパラメータ名。
	 */
	public static final String LAYOUT_MODE = "LAYOUT_MODE";

	/**
	 * 画面が作成される時に発生します。
	 *
	 * @param savedInstanceState 保存されたインスタンスの状態。
	 */
	@Override
	public void onCreate( Bundle savedInstanceState ) {
		super.onCreate( savedInstanceState );

		// 画面レイアウト
		Intent intent =  this.getIntent();
		this.setContentView( intent.getIntExtra( LAYOUT_ID, 0 ) );
		this.setTitle( intent.getStringExtra( LAYOUT_NAME ) );

		int layout = ( intent.getBooleanExtra( LAYOUT_MODE, true ) ? R.layout.tab_item_h : R.layout.tab_item_v );

		// タブ
		TabHost   host = this.getTabHost();
		Resources r    = this.getResources();

		host.addTab( createTabSpec( host, R.drawable.selector_icon_1, r.getString( R.string.display_name_1 ), layout, true  ) );
		host.addTab( createTabSpec( host, R.drawable.selector_icon_2, r.getString( R.string.display_name_2 ), layout, false ) );
		host.addTab( createTabSpec( host, R.drawable.selector_icon_3, r.getString( R.string.display_name_3 ), layout, false ) );
		host.addTab( createTabSpec( host, R.drawable.selector_icon_4, r.getString( R.string.display_name_4 ), layout, false ) );
	}

	/**
	 * タブを生成します。
	 *
	 * @param owner  タブ画面。
	 * @param icon   アイコンのリソース識別子。
	 * @param text   テキスト。
	 * @param layout タブのレイアウトを示すリソース識別子。
	 *
	 * @return 生成されたタブ情報。
	 */
	private TabSpec createTabSpec( TabHost host, int icon, String text, int layout, boolean isFirst ) {
		View v = LayoutInflater.from( this ).inflate( layout, null );

		// 始点なら区切り線を消す
		if( isFirst ) {
			v.findViewById( R.id.tab_item_separator ).setBackgroundColor( 0 );
		}

		( ( ImageView )v.findViewById( R.id.tab_item_icon ) ).setImageResource( icon );
		( ( TextView  )v.findViewById( R.id.tab_item_text ) ).setText( text );

		TabSpec spec = host.newTabSpec( text );
		spec.setIndicator( v );

		Intent intent = new Intent();
		intent.setClass( this, ChildDisplayActivity.class );
		intent.putExtra( ChildDisplayActivity.DISPLAY_NAME, text );
		spec.setContent( intent );

		return spec;
	}
}
